@@ -17,11 +17,12 @@ export EXEC_PATH=${0%/*}
 . ${EXEC_PATH}/install.cfg
 
 echo ""
-																				
+
+																			
 echo "###################################################################"
 echo "###                                                             ###"
 echo "### 運用管理ソフトウェア Hinemos  エージェント                  ###"
-echo "###                                   インストーラ   Ver 2.4.0  ###"
+echo "###                                   インストーラ   Ver 2.4.2  ###"
 echo "###                                                             ###"
 echo "###  Copyright (C) 2006-2008 NTT DATA Corporation.              ###"
 echo "###################################################################"
@@ -484,16 +485,34 @@ do
 						echo ""
 
 						# ジョブエージェントへのマネージャIPアドレスの反映
-						sed "s/%%manager%%/$IPADDR/" ${HINEMOS_AGENT_HOME}/lib/agent/Agent.properties > ${HINEMOS_AGENT_HOME}/lib/agent/Agent.properties_tmp
-						mv -f ${HINEMOS_AGENT_HOME}/lib/agent/Agent.properties_tmp ${HINEMOS_AGENT_HOME}/lib/agent/Agent.properties
+						echo "" >> ${HINEMOS_AGENT_HOME}/lib/agent/Agent.properties
+						echo "### Hinemos Manager ###" >> ${HINEMOS_AGENT_HOME}/lib/agent/Agent.properties
+						echo java.naming.provider.url=jnp://$IPADDR:1099 >> ${HINEMOS_AGENT_HOME}/lib/agent/Agent.properties
+						echo "" >> ${HINEMOS_AGENT_HOME}/lib/agent/Agent.properties
+
+						# ジョブエージェントのログ出力先設定
+						echo "" >> ${HINEMOS_AGENT_HOME}/lib/agent/log4j.properties
+						echo "### log directory setting ###" >> ${HINEMOS_AGENT_HOME}/lib/agent/log4j.properties
+						echo log4j.appender.file.File=${HINEMOS_AGENT_HOME}/var/log/agents.log >> ${HINEMOS_AGENT_HOME}/lib/agent/log4j.properties
+						echo "" >> ${HINEMOS_AGENT_HOME}/lib/agent/log4j.properties		
 
 						# ログ転送エージェントへのマネージャIPアドレスの反映
-						sed "s/%%manager%%/$IPADDR/" ${HINEMOS_AGENT_HOME}/lib/log_agent/Agent.properties > ${HINEMOS_AGENT_HOME}/lib/log_agent/Agent.properties_tmp
-						mv -f ${HINEMOS_AGENT_HOME}/lib/log_agent/Agent.properties_tmp ${HINEMOS_AGENT_HOME}/lib/log_agent/Agent.properties
-
-						#ログへのホスト名の反映のための設定
-						sed "s/%%HOST%%/$HOST/" ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties > ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties_tmp
-						mv -f ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties_tmp  ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties
+						echo "" >> ${HINEMOS_AGENT_HOME}/lib/log_agent/Agent.properties
+						echo "### Hinemos Manager ###" >> ${HINEMOS_AGENT_HOME}/lib/log_agent/Agent.properties
+						echo java.naming.provider.url=jnp://$IPADDR:1099 >> ${HINEMOS_AGENT_HOME}/lib/log_agent/Agent.properties
+						echo "" >> ${HINEMOS_AGENT_HOME}/lib/log_agent/Agent.properties
+						
+						# ログへのホスト名の反映のための設定
+						echo "" >> ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties
+						echo "### syslog host setting ###" >> ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties
+						echo log4j.appender.syslog.SyslogHost=$HOST >> ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties
+						echo "" >> ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties
+						
+						# ログ転送エージェントのログ出力先設定
+						echo "" >> ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties
+						echo "### log directory setting ###" >> ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties
+						echo log4j.appender.file.File=${HINEMOS_AGENT_HOME}/var/log/logagent.log >> ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties
+						echo "" >> ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties
 			  
 						#Net-SNMPのセットアップ
 						snmp_setting
